@@ -25,13 +25,15 @@
 
 #include <config.h>
 
+#define CLUTTER_ENABLE_EXPERIMENTAL_API
+#define COGL_ENABLE_EXPERIMENTAL_API
+
 #include <meta/meta-shaped-texture.h>
 #include "meta-texture-tower.h"
 #include "meta-texture-rectangle.h"
 
 #include <clutter/clutter.h>
 #include <cogl/cogl.h>
-#define COGL_ENABLE_EXPERIMENTAL_API
 #include <cogl/cogl-texture-pixmap-x11.h>
 #include <gdk/gdk.h> /* for gdk_rectangle_intersect() */
 #include <string.h>
@@ -54,6 +56,8 @@ static void meta_shaped_texture_get_preferred_height (ClutterActor *self,
 
 static void meta_shaped_texture_dirty_mask (MetaShapedTexture *stex);
 
+static gboolean meta_shaped_texture_get_paint_volume (ClutterActor *self, ClutterPaintVolume *volume);
+
 G_DEFINE_TYPE (MetaShapedTexture, meta_shaped_texture,
                CLUTTER_TYPE_ACTOR);
 
@@ -94,6 +98,7 @@ meta_shaped_texture_class_init (MetaShapedTextureClass *klass)
   actor_class->get_preferred_height = meta_shaped_texture_get_preferred_height;
   actor_class->paint = meta_shaped_texture_paint;
   actor_class->pick = meta_shaped_texture_pick;
+  actor_class->get_paint_volume = meta_shaped_texture_get_paint_volume;
 
   g_type_class_add_private (klass, sizeof (MetaShapedTexturePrivate));
 }
@@ -552,6 +557,13 @@ meta_shaped_texture_get_preferred_height (ClutterActor *self,
     *natural_height_p = priv->tex_height;
 }
 
+static gboolean
+meta_shaped_texture_get_paint_volume (ClutterActor *self,
+                                      ClutterPaintVolume *volume)
+{
+  return clutter_paint_volume_set_from_allocation (volume, self);
+}
+
 ClutterActor *
 meta_shaped_texture_new (void)
 {
@@ -698,7 +710,11 @@ meta_shaped_texture_set_pixmap (MetaShapedTexture *stex,
   priv->pixmap = pixmap;
 
   if (pixmap != None)
-    set_cogl_texture (stex, cogl_texture_pixmap_x11_new (pixmap, FALSE));
+    {
+      CoglContext *ctx =
+        clutter_backend_get_cogl_context (clutter_get_default_backend ());
+      set_cogl_texture (stex, cogl_texture_pixmap_x11_new (ctx, pixmap, FALSE, NULL));
+    }
   else
     set_cogl_texture (stex, COGL_INVALID_HANDLE);
 
